pub enum Grammar {
ObjectScript,
Sql,
Python,
Markdown,
Mdx,
Xml,
}Variants
Implementations
Sourceimpl Grammar
impl Grammar
Sourcepub fn from_name(input: &str) -> Option<Self>
pub fn from_name(input: &str) -> Option<Self>
Parses a grammar name or alias into a Grammar value.
The input is normalized to lowercase alphanumeric characters, so values
such as "ObjectScript", "objectscript-playground", and "os" are accepted.
Sourcepub fn canonical_name(self) -> &'static str
pub fn canonical_name(self) -> &'static str
Returns the canonical lowercase name for this grammar.
Sourcepub fn supported_names() -> &'static [&'static str]
pub fn supported_names() -> &'static [&'static str]
Returns the canonical grammar names accepted by the CLI-facing APIs.